@@ -1,5 +1,7 @@
 # ABSTRACT: ponapi command-line utility
 package PONAPI::CLI;
+use strict;
+use warnings;
 use App::Cmd::Setup -app;
 1;
 
@@ -15,7 +17,7 @@ PONAPI::CLI - ponapi command-line utility
 
 =head1 VERSION
 
-version 0.002009
+version 0.002010
 
 =head1 AUTHORS
 
